translate.lang.code_or.code_or

Package translate :: Package lang :: Module code_or :: Class code_or |
[hide private]
[frames] | no frames]

# Class code_or

source code

This class represents Oriya.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__`, `alter_length`, `length_difference` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `common.Common`: `capsstart`, `character_iter`, `characters`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| sentenceend = ``u'``।!?…``'`` These marks can indicate a sentence end.
| sentencere = `re.compile(r'`(?sx)`.`*?``[`\u0964!\?\u2026`]`\s`+``(?=``[``^`a`-`z`...``
| puncdict = ``{``...`` A dictionary of punctuation transformation rules that can be used by punctranslate().
| ignoretests = ``[``'``startcaps``'``,` `'``simplecaps``'``]`` List of pofilter tests for this language that must be ignored.
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `punctuation`, `quotes`, `rtlpunc`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### sentencere Value:
      re.compile(r'(?sx).*?[\u0964!\?\u2026]\s+(?=[^a-z\d])')

  ### puncdict A dictionary of punctuation transformation rules that can be used by punctranslate(). Value:
      {u'''.
      ''': u'''।
      ''',
       u'. ': u'। '}